@@ -1,6 +1,6 @@
 test_that("Package output matches TAXSIM test file", {
 
-  # example test from TAXSIM http://users.nber.org/~taxsim/taxsim35/low-level-remote.html
+  # example test from TAXSIM http://taxsim.nber.org/taxsim35/low-level-remote.html
   taxsim_input <- data.frame(
     taxsimid = 1,
     mstat = 2,
@@ -8,11 +8,11 @@ test_that("Package output matches TAXSIM test file", {
     ltcg = 100000
   )
 
-  taxsim_output <- taxsim_calculate_taxes(taxsim_input, return_all_information = FALSE, interface = "wasm")
+  taxsim_output <- taxsim_calculate_taxes(taxsim_input, return_all_information = FALSE)
 
   federal_taxes <- taxsim_output$fiitax
 
-  # number from http://users.nber.org/~taxsim/taxsim35/low-level-remote.html
+  # number from http://taxsim.nber.org/taxsim35/low-level-remote.html
   test_result <- 16700.04
 
   expect_equal(federal_taxes, test_result)
@@ -46,8 +46,8 @@ test_that("Output is correct (including marital status)", {
   n_col_short <- 8
   n_col_long <- 44
 
-  taxsim_output_short <- taxsim_calculate_taxes(taxsim_input, return_all_information = FALSE, interface = "wasm")
-  taxsim_output_long <- taxsim_calculate_taxes(taxsim_input, return_all_information = TRUE, interface = "wasm")
+  taxsim_output_short <- taxsim_calculate_taxes(taxsim_input, return_all_information = FALSE)
+  taxsim_output_long <- taxsim_calculate_taxes(taxsim_input, return_all_information = TRUE)
 
   # test that ID numbers are equal
   expect_equal(taxsim_output_short$taxsimid, taxsim_input$taxsimid)
@@ -73,43 +73,9 @@ test_that("All states work", {
     state = states
   )
 
-  taxsim_output <- taxsim_calculate_taxes(taxsim_input, return_all_information = FALSE, interface = "wasm")
+  taxsim_output <- taxsim_calculate_taxes(taxsim_input, return_all_information = FALSE)
 
   # test that all states were returned
   expect_equal(nrow(taxsim_output), 50)
 
 })
-
-test_that("All interface options return same values", {
-
-  # don't run on CRAN
-  testthat::skip_on_cran()
-
-  # remove MA from test for now, because it is giving odd results from the server for v36_state_taxable_income
-  states <- state.abb[-21]
-
-  id_nums <- seq(1, length(states))
-
-  taxsim_input <- data.frame(
-    taxsimid = id_nums,
-    mstat = 2,
-    year = 2018,
-    pwages = 50000,
-    state = states
-  )
-
-  ssh_results <- taxsim_calculate_taxes(taxsim_input,
-                                        return_all_information = T,
-                                        interface = 'ssh')
-
-  http_results <- taxsim_calculate_taxes(taxsim_input,
-                                         return_all_information = T,
-                                         interface = 'http')
-
-  wasm_results <- taxsim_calculate_taxes(taxsim_input,
-                                         return_all_information = T,
-                                         interface = 'wasm')
-
-  expect_equal(ssh_results, http_results)
-  expect_equal(ssh_results, wasm_results)
-})
